.. Copyright 2016, 2017 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Documentation for developers
============================

.. toctree::
   :maxdepth: 2

   Reahl source code <sourcecode>
   Development environment <devenv>
   Coding and design conventions <conventions>
   testing

   ownwidget
   dependencyinjection


